<?php

namespace Drupal\lb_branch_hours_blocks;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Contains HoursToday class.
 */
class HoursToday implements TrustedCallbackInterface {

  use StringTranslationTrait;

  /**
   * ConfigFactory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * System time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  public function __construct(ConfigFactoryInterface $config_factory, TimeInterface $time) {
    $this->configFactory = $config_factory;
    $this->time = $time;
  }

  /**
   * Get today hours.
   *
   * @return array
   *   Renderable array of today hours.
   */
  public function generateHoursToday() {
    $request_time = $this->time->getRequestTime();
    $hours = func_get_args();
    $days = [
      'Monday',
      'Tuesday',
      'Wednesday',
      'Thursday',
      'Friday',
      'Saturday',
      'Sunday',
    ];

    $date = DrupalDateTime::createFromTimestamp($request_time, $this->configFactory->get('system.date')->get('timezone')['default']);
    $today = $date->format('l');

    $idx = array_search($today, $days);
    $label = !empty($hours[$idx]) ? $this->t('Open today') : $this->t('Closed today');

    return [
      '#markup' => '<div class="today">'. $label . '<br />' . $hours[array_search($today, $days)] . '</div>',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['generateHoursToday'];
  }

}
